@@ -18,7 +18,8 @@ DespotifyWrap::DespotifyWrap() {
     this->initialized = despotify_init();
 
     if(this->initialized){
-        this->ds = despotify_init_client(callback, NULL, true);
+        /* third argument false = use lowest bitrate */
+        this->ds = despotify_init_client(callback, NULL, false);
         if(!ds) {
             this->initialized = false;
             qDebug() << "despotify_init_client failed";
@@ -96,14 +97,14 @@ bool DespotifyWrap::Search(char *searchstring) {
 
      search_result* search;
 
-     this->player->Pause();
+     //this->player->Pause();
 
      search = despotify_search(this->ds, searchstring, MAX_SEARCH_RESULTS);
      if (!search) {
          qDebug() << " search failed: " << despotify_get_error(this->ds);
          return false;
      } else {
-         this->lastlist = search->playlist;
+         this->pending_list = search->playlist;
          return true;
      }
 
