@@ -18,6 +18,7 @@ MainWindow::MainWindow(QWidget *parent) :
     /* Connect signals */
     this->connect(this->dw, SIGNAL(PlaylistsUpdated()),this, SLOT(PlaylistsUpdated()));
     this->connect(&dc, SIGNAL(NewTrack(int,int,int,track*)),this, SLOT(NewTrack(int,int,int,track*)));
+    this->connect(&dc, SIGNAL(EndOfPlaylist()),this, SLOT(EndOfPlaylist()));
     this->connect(&dc, SIGNAL(TellTime(int,int,int)),this, SLOT(TellTime(int,int,int)));
 
     this->connect(this->dw->player, SIGNAL(Playing()),this, SLOT(Playing()));
@@ -60,6 +61,8 @@ void MainWindow::on_pushButton_5_clicked()
 
 void MainWindow::on_pbLogin_clicked()
 {
+
+
     /* Convert lineedit text to char* */
     QByteArray user = this->ui->leLogin->text().toLatin1();
     char *c_user = user.data();
@@ -67,15 +70,20 @@ void MainWindow::on_pbLogin_clicked()
     char *c_pass = pass.data();
 
     /* Try to authenticate */
+    this->ui->lblLoginError->setText(tr("Authenticating..."));
+    qApp->processEvents();
+
     if(!this->dw->Authenticate(c_user,c_pass)) {
+        qDebug() << "Authentication failure";
         this->ui->lblLoginError->setText(tr("Incorrect credentials entered\nplease try again."));
     } else {
-        this->ui->lblLoginError->setText(QString(""));
 
-        /* Show inside widget */
-        this->ui->swWidgets->setCurrentWidget(this->ui->pgInside);
+        qDebug() << "Authentication successful";
 
         /* Update playlists */
+        this->ui->lblLoginError->setText(tr("Updating playlists..."));
+        qApp->processEvents();
+
         this->dw->UpdatePlaylists();
     }
 }
@@ -84,6 +92,9 @@ void MainWindow::PlaylistsUpdated() {
 
     qDebug() << "Received signal: PlaylistsUpdated";
 
+    /* Show inside widget */
+    this->ui->swWidgets->setCurrentWidget(this->ui->pgInside);
+
     /* Clear list */
     this->ui->cbPlaylists->clear();
 
@@ -93,7 +104,8 @@ void MainWindow::PlaylistsUpdated() {
         for (p; p; p = p->next)
         {
             if(p != NULL) {
-                this->ui->cbPlaylists->addItem(QString(p->name),QString((char*)p->playlist_id));
+                this->ui->cbPlaylists->addItem(QString::fromUtf8(p->name), QString::fromUtf8((char*)p->playlist_id));
+                qDebug() << "Playlist_id: " << p->playlist_id;
             } else {
                 qDebug() << "This really shouldn't happen... really...";
             }
@@ -105,27 +117,26 @@ void MainWindow::PrintTracks() {
 
     this->ui->twSongs->clear();
 
-    track* head = this->dw->lastlist->tracks;
+    track* head = this->dw->pending_list->tracks;
     int count=0;
     for (track* t = head; t; t = t->next) {
         if (t->has_meta_data) {
             //wrapper_wprintf(L"%3d: %-40s %2d:%02d ", count++, t->title,t->length / 60000, t->length % 60000 / 1000);
-            QString t_artist = QString("");
+            QString t_artist;
 
             for (struct artist* a = t->artist; a; a = a->next)
-                t_artist += a->name;
-            t_artist = t_artist.toLatin1();
+                t_artist += QString().fromUtf8(a->name);
 
-            QString t_song = QString(t->title).toLatin1();
+            QString t_song = QString().fromUtf8(t->title);
             QString t_length = QString("%1:%2").arg((int)(t->length / 60000),2,10,QChar('0')).arg((int)(t->length % 60000 / 1000),2,10,QChar('0'));
-            QString t_album = QString(t->album).fromUtf8(t->album);
+            QString t_album = QString().fromUtf8(t->album);
             QString t_popularity = QString().setNum(t->popularity);
 
             /* Check if song is playable */
             if(t->playable) {
 
                 QTreeWidgetItem *t_item = new QTreeWidgetItem(this->ui->twSongs);
-                t_item->setText(0, QString("%1").arg(count,3,10,QChar(' ')));
+                t_item->setText(0, QString("%1").arg(count + 1,3,10,QChar(' ')));
                 t_item->setText(1, t_song);
                 t_item->setText(2, t_artist);
                 t_item->setText(3, t_album);
@@ -148,10 +159,8 @@ void MainWindow::on_pbShowPlaylist_clicked()
     /* Iterate through all playlists */
     for (playlist* p = this->dw->GetPlaylists(); p; p = p->next)
     {
-        /* ToDo : Use ID */
-        if(QString((char*)p->name) == this->ui->cbPlaylists->currentText()) {
-            qDebug() << "Print tracks";
-            this->dw->lastlist = p;
+        if(QString((char*)p->playlist_id) == this->ui->cbPlaylists->itemData(this->ui->cbPlaylists->currentIndex())) {
+            this->dw->pending_list = p;
             this->PrintTracks();
         }
     }
@@ -160,7 +169,10 @@ void MainWindow::on_pbShowPlaylist_clicked()
 void MainWindow::on_twSongs_itemDoubleClicked(QTreeWidgetItem* item, int column)
 {
     qDebug() << "Playing offset " << QString(item->text(0));
-    this->dw->Play(QString(item->text(0)).toInt());
+    if(this->dw->pending_list){
+        this->dw->lastlist = this->dw->pending_list;
+    }
+    this->dw->Play(QString(item->text(0)).toInt()-1);
 }
 
 void MainWindow::on_pbSearch_clicked()
@@ -197,6 +209,12 @@ void MainWindow::NewTrack(int min, int sec, int totsec, track *t) {
     this->song_tot_len=totsec;
     this->ui->hsElapsed->setMaximum(totsec);
 
+}
+void MainWindow::EndOfPlaylist() {
+
+    /* Force player to try to pley next song (=first song) */
+    this->dw->PlayNext();
+
 }
 
 void MainWindow::TellTime(int min, int sec, int totsec) {
